Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1037)

Unified Diff: lib/core/object.dart

Issue 11231074: Change signature of noSuchMethod to take an InvocationMirror. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: One more test expectation Created 8 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « lib/core/errors.dart ('k') | lib/html/dartium/html_dartium.dart » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: lib/core/object.dart
diff --git a/lib/core/object.dart b/lib/core/object.dart
index ba41cb81840162b11f00a9e5fbd31f20c63a0c9f..4ab04bca8155661b38d34999f9f60204b549ceec 100644
--- a/lib/core/object.dart
+++ b/lib/core/object.dart
@@ -48,14 +48,15 @@ class Object {
/**
* [noSuchMethod] is invoked when users invoke a non-existant method
* on an object. The name of the method and the arguments of the
* invocation are passed to [noSuchMethod]. If [noSuchMethod]
* returns a value, that value becomes the result of the original
* invocation.
*
* The default behavior of [noSuchMethod] is to throw a
* [noSuchMethodError].
*/
- external Dynamic noSuchMethod(String name, List args);
+ external dynamic noSuchMethod(InvocationMirror invocation);
+
/**
* A representation of the runtime type of the object.
*/
@@ -48,14 +48,15 @@ class Object {
* [noSuchMethod] is invoked when users invoke a non-existant method
* on an object. The name of the method and the arguments of the
- * invocation are passed to [noSuchMethod]. If [noSuchMethod]
- * returns a value, that value becomes the result of the original
- * invocation.
+ * invocation are passed to [noSuchMethod] in an [InvocationMirror].
+ * If [noSuchMethod] returns a value, that value becomes the result of
+ * the original invocation.
*
* The default behavior of [noSuchMethod] is to throw a
« no previous file with comments | « lib/core/errors.dart ('k') | lib/html/dartium/html_dartium.dart » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698